pub enum VerticalMovementAxis {
World,
Local,
}Expand description
Whether the vertical inputs translate the camera in world or local space axes.
Variants
World
Vertical movement is aligned to the world.
This is the default behavior in Bevy, Unreal and Blender.
Local
Vertical movement follows the camera’s rotation.
This is the default behavior in Unity and Godot.